@@ -1,9 +1,9 @@
 """Init for Nbed package."""
 
+from .config import NbedConfig
 from .embed import nbed
-from .ham_converter import load_hamiltonian
 from .utils import setup_logs
 
-__all__ = ["nbed", "load_hamiltonian"]
+__all__ = ["nbed", "NbedConfig"]
 
 setup_logs()
